@@ -7,3 +7,6 @@ STATIC_FILES_PATH = getattr(settings, 'STATIC_FILES_PATH', 'uploads')
 
 ROBOT_PROTECTION_DOMAIN = getattr(settings, 'ROBOT_PROTECTION_DOMAIN', None)
 
+RESULT_OK = getattr(settings, 'RESULT_OK', 'ok')
+RESULT_ERROR = getattr(settings, 'RESULT_ERROR', 'error')
+
