@@ -11,6 +11,7 @@ from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
 
 from djangoplus.templatetags.djangoplus_tags import moneyformat
+from djangoplus import app_settings
 
 class ModelInfoBase(object):
     class _Meta:
@@ -319,7 +320,7 @@ class ModelList(ModelInfoBase):
                 val = '&nbsp'
             
             if isinstance(val, decimal.Decimal):
-                val = moneyformat(val)
+                val = moneyformat(val, None, app_settings.THOUSANDS_SEPARATOR)
 
             tsummary.append(self._meta.summary_td_template%{
                 'field_name': f_name,
@@ -397,7 +398,7 @@ class ModelList(ModelInfoBase):
                     )
 
             if isinstance(f_value, decimal.Decimal):
-                f_value = moneyformat(f_value)
+                f_value = moneyformat(f_value, None, app_settings.THOUSANDS_SEPARATOR)
 
             if self._meta.show_if_none or f_value is not None:
                 row.append(td_template%{'field_name': f_name, 'value': f_value})
